# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_credential) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-DESC
    This resource allows you to manage user in an WebLogic Security Realm.

    Here is an example on how you should use this:

        wls_credential { 'oracle.wsm.security/keystore-csf-key':
          ensure      => 'present',
          username    => 'osbkey',
          password    => 'secret stuff',
          description => 'keystore csf key for osbkey',
        }

    In this example you are managing a user in the default domain. When you want to
    manage a user in a specific domain, you can use:

        # this will use default as wls_setting identifier
        wls_credential { 'my_domain/oracle.wsm.security/keystore-csf-key':
          ensure      => 'present',
          username    => 'osbkey',
          password    => 'secret stuff',
          description => 'keystore csf key for osbkey',
        }

    DESC

    ensurable

    on_prefetch do |resources, provider|
      prefetching_for(:wls_credential, resources, provider)
    end

    to_get_raw_resources do
      []
    end

    on_create do
      Puppet.info "create #{name}"
      wlst template('wls_config/wls_credential/create.py.erb', binding)
      nil
    end

    on_modify do
      Puppet.info "modify #{name} "
      wlst template('wls_config/wls_credential/modify.py.erb', binding)
      nil
    end

    on_destroy do
      Puppet.info "destroy #{name} "
      wlst template('wls_config/wls_credential/destroy.py.erb', binding)
      nil
    end

    parameter :domain
    parameter :name
    parameter :keymap
    parameter :key

    property :username
    property :password
    property :description

    add_title_attributes(:keymap, :key) do
      /(.+):(.+)/
    end
  end
end
