# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_credential_mapper) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-DESC
    This resource allows you to manage credential mappers in a WebLogic domain.

    Here is an example on how you should use this:

        wls_credential_mapper { 'dom0/VGZMapper':
          ensure => present,
          mapperclassname => 'weblogic.security.providers.credentials.PKICredentialMapper',
          mapper_specific => {
            'KeyStoreType'          => 'JKS',
            'KeyStoreFileName'      => '/security/mykeystore.jks',
            'KeyStorePassPhrase'    => 'secretstuff',
            'UseResourceHierarchy'   => 0,
            'UseInitiatorGroupNames' => 0,
          },
        }


    Check [the Oracle Weblogic documentation](https://docs.oracle.com/cd/E17904_01/web.1111/e13707/providers.htm#SECMG148)
    for more documentation about setting up and managing a WebLogic cluster.
    DESC

    ensurable

    to_get_raw_resources do
      Puppet.info "index #{name} "
      environment = { 'action' => 'index', 'type' => 'wls_credential_mapper' }
      wlst template('wls_config/wls_credential_mapper/index.py.erb', binding), environment
    end

    on_create do
      Puppet.info "create #{name} "
      wlst template('wls_config/wls_credential_mapper/create.py.erb', binding)
      nil
    end

    on_modify do
      Puppet.info "modify #{name} "
      wlst template('wls_config/wls_credential_mapper/modify.py.erb', binding)
      nil
    end

    on_destroy do
      Puppet.info "destroy #{name} "
      wlst template('wls_config/wls_credential_mapper/destroy.py.erb', binding)
      nil
    end

    parameter :credential_mapper_name
    parameter :domain
    parameter :name
    parameter :timeout

    parameter :mapperclassname
    property :order
    property :mapper_specific

    add_title_attributes(:credential_mapper_name)
  end
end
