# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newparam(:mapperclassname) do
  include EasyType
  include EasyType::Validators::Name

  desc <<-DESC
  The mapper class name.

  This is the class name of the credential mapper  you are creating. This is a parameter
  and will only be used during creation of the mapper. **You cannot change a class name of a mapper.**

      wls_credential_mapper{'my_mapper':
        ...
        mapperclassname => 'PKICredentialMapper'
        ...
      }

  Valid values are:

  - com.bea.security.saml2.providers.SAML2CredentialMapper
  - weblogic.security.providers.credentials.DefaultCredentialMapper
  - weblogic.security.providers.credentials.PKICredentialMapper
  - weblogic.security.providers.saml.SAMLCredentialMapperV2


  **ATTENTION:**

  Most of the properties from the wls_authentication_provider need a restart from the Admin server.
  If you don't restart the server, the changes will not be applied, and Puppet will redo them.

  Check [The WebLogic documentation](http://docs.oracle.com/cd/E17904_01/web.1111/e13707/atn.htm#SECMG169) for
  a list of valid classes.

  DESC

  defaultto 'weblogic.security.providers.credentials.DefaultCredentialMapper'

  to_translate_to_resource do |raw_resource|
    raw_resource['mapperclassname']
  end
end
